==> eiffelstudio-18.11.10.2592.tar: F_code/C5/xm213.c <==
/*
 * Code for class XML_STOPPABLE_PARSER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm213.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_STOPPABLE_PARSER}.reset */
void F259_3300 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F258_3224(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_4_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.checkpoint_position */
EIF_REFERENCE F259_3301 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) > ((EIF_INTEGER_32) 0L))) {
		tr1 = RTLNS(eif_new_type(1033, 0x00).id, 1033, _OBJSIZ_1_0_0_3_0_0_0_0_);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3134[Dtype(tr2)-263])(RTCW(tr2));
		tr2 = F1016_7458(RTCW(tr2));
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_);
		ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_);
		F1034_8017(RTCW(tr1), tr2, ti4_1, ti4_2, ti4_3);
		Result = (EIF_REFERENCE) tr1;
	}
	RTLE;
	return Result;
}

/* {XML_STOPPABLE_PARSER}.set_checkpoint_position */
void F259_3305 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = F258_3222(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F258_3223(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F258_3221(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.unset_checkpoint_position */
void F259_3306 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.report_error */
void F259_3307 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	F258_3239(Current, arg1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_5_3_);
	RTLE;
}

void EIF_Minit213 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/xm213.c <==
/*
 * Code for class XML_STOPPABLE_PARSER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm213.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_STOPPABLE_PARSER}.reset */
void F259_3292 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F258_3216(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_4_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.checkpoint_position */
EIF_REFERENCE F259_3293 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) > ((EIF_INTEGER_32) 0L))) {
		Result = RTLNS(eif_new_type(1035, 0x00).id, 1035, _OBJSIZ_1_0_0_3_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3124[Dtype(RTCW(tr1))-265])(tr1);
		tr1 = F1017_7481(RTCW(tr1));
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_);
		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_);
		ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_);
		F1036_8057(RTCW(Result), tr1, ti4_1, ti4_2, ti4_3);
	}
	RTLE;
	return Result;
}

/* {XML_STOPPABLE_PARSER}.set_checkpoint_position */
void F259_3297 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = F258_3214(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F258_3215(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_) = (EIF_INTEGER_32) ti4_1;
	ti4_1 = F258_3213(Current);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_) = (EIF_INTEGER_32) ti4_1;
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.unset_checkpoint_position */
void F259_3298 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_5_0_4_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	RTLE;
}

/* {XML_STOPPABLE_PARSER}.report_error */
void F259_3299 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	F258_3231(Current, arg1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_5_3_);
	RTLE;
}

void EIF_Minit213 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
